@@ -1,3 +1,12 @@
+/*
+ * CameraFile.cs
+ *
+ * Author(s):
+ *	Ewen Cheslack-Postava <echeslack@gmail.com>
+ *	Larry Ewing <lewing@novell.com>
+ *
+ * This is free software. See COPYING for details.
+ */
 using System;
 using System.Runtime.InteropServices;
 
@@ -27,14 +36,7 @@ namespace LibGPhoto2
 		[MarshalAs(UnmanagedType.LPTStr)] public static string UNKNOWN = "application/octet-stream";
 		[MarshalAs(UnmanagedType.LPTStr)] public static string WAV = "audio/wav";
 	}
-	
-	[StructLayout(LayoutKind.Sequential)]
-	internal unsafe struct _CameraFile  {
 
-
-
-	}
-	
 	public class CameraFile : Object 
 	{
 		[DllImport ("libgphoto2.so")]
@@ -223,9 +225,10 @@ namespace LibGPhoto2
 				IntPtr data_addr = IntPtr.Zero;
 				Error.CheckError (gp_file_get_data_and_size (this.Handle, out data_addr, out size));
 				data = new byte[size];
-				Marshal.Copy(data_addr, data, 0, (int)size);
+				if (data_addr != IntPtr.Zero && size > 0)
+					Marshal.Copy(data_addr, data, 0, (int)size);
 			}
-
+			
 			return data;
 		}
 	}
