@@ -5,6 +5,7 @@ using System.Collections;
 using System;
 using FSpot;
 using FSpot.Xmp;
+using FSpot.UI.Dialog;
 using System.IO;
 using Mono.Unix;
 
@@ -80,7 +81,7 @@ public class FileImportBackend : ImportBackend {
 				if (id == Photo.OriginalVersionId)
 				        name = p.Name;
 				else 
-					name = (new System.IO.FileInfo (p.GetVersionPath (id))).Name;
+					name = (new System.IO.FileInfo (p.VersionUri (id).LocalPath)).Name;
 
 				exiting_entries [name] = p;
 			}
@@ -169,13 +170,13 @@ public class FileImportBackend : ImportBackend {
 			// Split dest_dir into constituent parts so we can clean up each individual directory in
 			// event of a cancel.
 			if (created_directories != null) {
-				string [] parts = dest_dir.Split (new char [] {'/'});
+				string [] parts = dest_dir.Split (new char [] {System.IO.Path.DirectorySeparatorChar});
 				string nextPath = String.Empty;
 				for (int i = 0; i < parts.Length; i++) {
 					if (i == 0)
 						nextPath += parts [i];
 					else
-						nextPath += "/" + parts [i];
+						nextPath += System.IO.Path.DirectorySeparatorChar + parts [i];
 					if (nextPath.Length > 0) {
 						info = new System.IO.DirectoryInfo (nextPath);
 						// only add the directory path if it didn't already exist and we haven't already added it.
@@ -264,7 +265,7 @@ public class FileImportBackend : ImportBackend {
 									     Gtk.ButtonsType.Cancel,
 									     Catalog.GetString ("Import error"),
 									     String.Format(Catalog.GetString ("Error importing {0}{2}{2}{1}"), info.OriginalPath, e.Message, Environment.NewLine ));
-			errordialog.AddButton ("Skip", Gtk.ResponseType.Reject, false);
+			errordialog.AddButton (Catalog.GetString ("Skip"), Gtk.ResponseType.Reject, false);
 			ResponseType response = (ResponseType) errordialog.Run ();
 			errordialog.Destroy ();
 			if (response == ResponseType.Cancel)
