@@ -1,5 +1,6 @@
 using System;
 using System.IO;
+using FSpot.Utils;
 
 namespace FSpot {
 	public class ImageFormatException : ApplicationException {
@@ -15,7 +16,7 @@ namespace FSpot {
 
 		public ImageFile (string path) 
 		{
-			this.uri = UriList.PathToFileUri (path);
+			this.uri = UriUtils.PathToFileUri (path);
 		}
 		
 		public ImageFile (Uri uri)
@@ -54,6 +55,7 @@ namespace FSpot {
 			name_table [".pef"] = typeof (FSpot.Tiff.NefFile);
 			name_table [".raw"] = typeof (FSpot.Tiff.NefFile);
 			name_table [".kdc"] = typeof (FSpot.Tiff.NefFile);
+			name_table [".arw"] = typeof (FSpot.Tiff.NefFile);
 			name_table [".tiff"] = typeof (FSpot.Tiff.TiffFile);
 			name_table [".tif"] = typeof (FSpot.Tiff.TiffFile);
 			name_table [".orf"] =  typeof (FSpot.Tiff.NefFile);
@@ -151,7 +153,7 @@ namespace FSpot {
 
 		public static bool HasLoader (string path)
 		{
-			return HasLoader (UriList.PathToFileUri (path));
+			return HasLoader (UriUtils.PathToFileUri (path));
 		}
 		
 		public static bool HasLoader (Uri uri)
@@ -165,7 +167,7 @@ namespace FSpot {
 
 		public static ImageFile Create (string path)
 		{
-			return Create (UriList.PathToFileUri (path));
+			return Create (UriUtils.PathToFileUri (path));
 		}
 
 		public static ImageFile Create (Uri uri)
@@ -211,5 +213,23 @@ namespace FSpot {
 		protected virtual void Close ()
 		{
 		}
+
+		public static bool IsRaw (string name)
+		{
+			string [] raw_extensions = {".nef", ".crw", ".cr2", ".arw", ".mrw", ".pef", ".dng"};
+			foreach (string ext in raw_extensions)
+				if (ext == System.IO.Path.GetExtension (name).ToLower ())
+					return true;
+			return false;
+		}
+
+		public static bool IsJpeg (string name)
+		{
+			string [] jpg_extensions = {".jpg", ".jpeg"};
+			foreach (string ext in jpg_extensions)
+				if (ext == System.IO.Path.GetExtension (name).ToLower ())
+					return true;
+			return false;
+		}
 	} 
 }
