@@ -13,9 +13,10 @@ using Gtk;
 using Mono.Unix;
 using FSpot.Filters;
 using System;
+using FSpot.UI.Dialog;
 
 namespace FSpot {
-	public abstract class ItemAction : Action {
+	public abstract class ItemAction : Gtk.Action {
 		protected BrowsablePointer item;
 
 		public ItemAction (BrowsablePointer pointer,
@@ -155,7 +156,7 @@ namespace FSpot {
 			photo = item.Current as Photo;
 			if (photo != null) {
 				version = photo.DefaultVersionId;
-				bool create = version == Photo.OriginalVersionId;
+				bool create = photo.DefaultVersion.IsProtected;
 				
 				if (create) {
 					version = photo.CreateDefaultModifiedVersion (photo.DefaultVersionId, false);
