@@ -4,6 +4,7 @@ using System.Runtime.InteropServices;
 using Cairo;
 using Mono.Unix;
 using FSpot.Widgets;
+using FSpot.UI.Dialog;
 
 namespace FSpot {
 	public class Sharpener : Loupe {
@@ -50,7 +51,7 @@ namespace FSpot {
 									    amount_spin.Value,
 									    threshold_spin.Value);
 				
-				bool create_version = photo.DefaultVersionId == Photo.OriginalVersionId;
+				bool create_version = photo.DefaultVersion.IsProtected;
 
 				photo.SaveVersion (final, create_version);
 			} catch (System.Exception e) {
@@ -160,14 +161,6 @@ namespace FSpot {
 			BuildUI ();
 		}
 
-		
-
-		[DllImport("libgdk-2.0-0.dll")]
-	        static extern bool gdk_screen_is_composited (IntPtr screen);
-		
-		[DllImport ("libgtk-win32-2.0-0.dll")]
-		static extern void gtk_widget_input_shape_combine_mask (IntPtr raw, IntPtr shape_mask, int offset_x, int offset_y);
-
 		Gdk.Point old_win_pos;
 		[GLib.ConnectBefore]
 		public void HandleToplevelConfigure (object o, ConfigureEventArgs args)
@@ -185,11 +178,6 @@ namespace FSpot {
 			old_win_pos.Y = args.Event.Y;
 		}
 		
-		public void InputShapeCombineMask(Gdk.Pixmap shape_mask, int offset_x, int offset_y)
-		{
-			gtk_widget_input_shape_combine_mask (Handle, shape_mask == null ? IntPtr.Zero : shape_mask.Handle, offset_x, offset_y);
-		}
-		
 		// FIXME
 		//screen "composited-changed"
 
@@ -314,18 +302,18 @@ namespace FSpot {
 							    Allocation.Width, 
 							    Allocation.Height, 1);
 			
-			Context g = CreateDrawable (bitmap);
+			Context g = CairoUtils.CreateContext (bitmap);
 			DrawShape (g, Allocation.Width, Allocation.Height);
 			((IDisposable)g).Dispose ();
 
 			if (use_shape_ext)
 				ShapeCombineMask (bitmap, 0, 0);
 			else {
-				Context rgba = CreateDrawable (GdkWindow);
+				Context rgba = CairoUtils.CreateContext (GdkWindow);
 				DrawShape (rgba, Allocation.Width, Allocation.Height);
 				((IDisposable)rgba).Dispose ();
 				try {
-					InputShapeCombineMask (bitmap, 0,0);
+					CompositeUtils.InputShapeCombineMask (this, bitmap, 0,0);
 				} catch (EntryPointNotFoundException) {
 					System.Console.WriteLine ("Warning: gtk+ version doesn't support input shapping");
 				}
@@ -413,7 +401,7 @@ namespace FSpot {
 
 		protected override bool OnExposeEvent (Gdk.EventExpose args)
 		{
-			Context g = CreateDrawable (GdkWindow);
+			Context g = CairoUtils.CreateContext (GdkWindow);
 			DrawShape (g, Allocation.Width, Allocation.Height);
 			//base.OnExposeEvent (args);
 			((IDisposable)g).Dispose ();
@@ -540,6 +528,19 @@ namespace FSpot {
 			dragging = false;
 		}
 
+		private void HandleKeyPressEvent (object sender, Gtk.KeyPressEventArgs args)
+		{
+			switch (args.Event.Key) {
+			case Gdk.Key.v:
+				Destroy ();
+				args.RetVal = true;
+				break;
+			default:
+				break;
+			}
+			return;
+		}
+
 		protected override void OnDestroyed ()
 		{
 			view.MotionNotifyEvent -= HandleImageViewMotion;
@@ -576,18 +577,6 @@ namespace FSpot {
 			gdk_cairo_set_source_pixbuf (ctx.Handle, pixbuf.Handle, x, y);
 		}
 
-		[DllImport("libgdk-2.0-0.dll")]
-		static extern IntPtr gdk_cairo_create (IntPtr raw);
-		
-		public static Cairo.Context CreateDrawable (Gdk.Drawable drawable)
-		{
-			Cairo.Context g = new Cairo.Context (gdk_cairo_create (drawable.Handle));
-			if (g == null) 
-				throw new Exception ("Couldn't create Cairo Context!");
-			
-			return g;
-		}
-		
 		protected override void OnSizeRequested (ref Requisition requisition) 
 		{
 			Layout ();
@@ -617,6 +606,8 @@ namespace FSpot {
 			ButtonReleaseEvent += HandleButtonReleaseEvent;
 			MotionNotifyEvent += HandleMotionNotifyEvent;
 
+			KeyPressEvent += HandleKeyPressEvent;
+
 			drag = new Delay (20, new GLib.IdleHandler (DragUpdate));
 		}
 	}
