@@ -1,7 +1,7 @@
 using Gtk;
 using GtkSharp;
 using System;
-
+using FSpot;
 public class PhotoVersionMenu : Menu {
 	private uint version_id;
 	public uint VersionId {
@@ -52,7 +52,7 @@ public class PhotoVersionMenu : Menu {
 
 		int i = 0;
 		foreach (uint id in version_ids) {
-			MenuItem menu_item = new MenuItem (photo.GetVersionName (id));
+			MenuItem menu_item = new MenuItem (photo.GetVersion (id).Name);
 			menu_item.Show ();
 			menu_item.Sensitive = true;
 			menu_item.Activated += new EventHandler (HandleMenuItemActivated);
