@@ -4,11 +4,14 @@ using Gtk;
 using GtkSharp;
 using System;
 using Mono.Unix;
+
 using FSpot.Xmp;
+using FSpot.Utils;
+using FSpot.UI.Dialog;
 
 namespace FSpot {
 public class PhotoView : EventBox {
-	FSpot.Delay description_delay; 
+	FSpot.Delay commit_delay; 
 
 	private bool has_selection = false;
 	private FSpot.PhotoImageView photo_view;
@@ -20,6 +23,7 @@ public class PhotoView : EventBox {
 	private Gtk.ToolButton display_next_button, display_previous_button;
 	private Label count_label;
 	private Entry description_entry;
+	private Widgets.Rating rating;
 
 	private Gtk.ToolButton crop_button;
 	private Gtk.ToolButton redeye_button;
@@ -190,14 +194,19 @@ public class PhotoView : EventBox {
 			description_entry.Text = String.Empty;
 		}
 
-		if (description_entry.Text != String.Empty)
-			tips.SetTip (description_entry, description_entry.Text, description_entry.Text);
-		else
-			tips.SetTip (description_entry, null, null);
+		tips.SetTip (description_entry, description_entry.Text ?? String.Empty, description_entry.Text ?? String.Empty);
 
 		description_entry.Changed += HandleDescriptionChanged;
 	}    
 
+	public void UpdateRating ()
+	{
+		rating.Changed -= HandleRatingChanged;
+		if (Item.IsValid)
+			rating.Value = (int)Item.Current.Rating;
+		rating.Changed += HandleRatingChanged;
+	}
+
 	private void Update ()
 	{
 		if (UpdateStarted != null)
@@ -206,6 +215,7 @@ public class PhotoView : EventBox {
 		UpdateButtonSensitivity ();
 		UpdateCountLabel ();
 		UpdateDescriptionEntry ();
+		UpdateRating ();
 
 		if (UpdateFinished != null)
 			UpdateFinished (this);
@@ -347,7 +357,7 @@ public class PhotoView : EventBox {
 				original_pixbuf.CopyArea (x, y, width, height, edited, 0, 0);
 			}
 			
-			bool create_version = photo.DefaultVersionId == Photo.OriginalVersionId;
+			bool create_version = photo.DefaultVersion.IsProtected;
 			photo.SaveVersion (edited, create_version);
 			((PhotoQuery)query).Commit (Item.Index);
 
@@ -371,12 +381,12 @@ public class PhotoView : EventBox {
 		ColorDialog.CreateForView (photo_view);
 	}	
 
-	int description_photo;
+	int changed_photo;
 	private bool CommitPendingChanges ()
 	{
-		if (description_delay.IsPending) {
-			description_delay.Stop ();
-			((PhotoQuery)query).Commit (description_photo);
+		if (commit_delay.IsPending) {
+			commit_delay.Stop ();
+			((PhotoQuery)query).Commit (changed_photo);
 		}
 		return true;
 	}
@@ -388,17 +398,33 @@ public class PhotoView : EventBox {
 		
 		((Photo)Item.Current).Description = description_entry.Text;
 		
-		if (description_delay.IsPending)
-			if (description_photo == Item.Index)
-				description_delay.Stop ();
+		if (commit_delay.IsPending)
+			if (changed_photo == Item.Index)
+				commit_delay.Stop ();
 			else
 				CommitPendingChanges ();
 		
 		tips.SetTip (description_entry, description_entry.Text, "This is a tip");
-		description_photo = Item.Index;
-		description_delay.Start ();
+		changed_photo = Item.Index;
+		commit_delay.Start ();
 	}
 
+	private void HandleRatingChanged (object o, EventArgs e)
+	{
+		if (!Item.IsValid)
+			return;
+
+		((Photo)Item.Current).Rating = (uint)(o as Widgets.Rating).Value;
+
+		if (commit_delay.IsPending)
+			if (changed_photo == Item.Index)
+				commit_delay.Stop();
+			else
+				CommitPendingChanges ();
+		changed_photo = Item.Index;
+		commit_delay.Start ();
+ 	}
+
 	private void HandlePhotoChanged (FSpot.PhotoImageView view)
 	{
 		if (query is PhotoQuery) {
@@ -434,7 +460,7 @@ public class PhotoView : EventBox {
 	{
 		this.query = query;
 
-		description_delay = new FSpot.Delay (1000, new GLib.IdleHandler (CommitPendingChanges));
+		commit_delay = new FSpot.Delay (1000, new GLib.IdleHandler (CommitPendingChanges));
 		this.Destroyed += HandleDestroy;
 
 		Name = "ImageContainer";
@@ -470,13 +496,18 @@ public class PhotoView : EventBox {
 
 		tag_view = new Widgets.TagView ();
 		inner_hbox.PackStart (tag_view, false, true, 0);
-		SetColors ();
 
 		Label comment = new Label (Catalog.GetString ("Comment:"));
 		inner_hbox.PackStart (comment, false, false, 0);
 		description_entry = new Entry ();
 		inner_hbox.PackStart (description_entry, true, true, 0);
 		description_entry.Changed += HandleDescriptionChanged;
+
+		rating = new Widgets.Rating();
+		inner_hbox.PackStart (rating, false, false, 0);
+		rating.Changed += HandleRatingChanged;
+
+		SetColors ();
 		
 		inner_vbox.PackStart (inner_hbox, false, true, 0);
 
@@ -557,10 +588,11 @@ public class PhotoView : EventBox {
 
 	private void SetColors ()
 	{
-		FSpot.Global.ModifyColors (tag_view);
-		FSpot.Global.ModifyColors (photo_view);
-		FSpot.Global.ModifyColors (background);
-		FSpot.Global.ModifyColors (photo_view_scrolled);
+		GtkUtil.ModifyColors (tag_view);
+		GtkUtil.ModifyColors (photo_view);
+		GtkUtil.ModifyColors (background);
+		GtkUtil.ModifyColors (photo_view_scrolled);
+		GtkUtil.ModifyColors (rating);
 	}
 
 	protected override void OnStyleSet (Style previous)
