@@ -4,6 +4,7 @@ using System.Runtime.InteropServices;
 using System;
 using System.IO;
 using FSpot;
+using FSpot.Utils;
 
 /**
   1        2       3      4         5            6           7          8
@@ -29,7 +30,7 @@ public enum PixbufOrientation {
 	LeftBottom = 8
 }
 
-class PixbufUtils {
+public class PixbufUtils {
 		
 	static public PixbufOrientation Rotate270 (PixbufOrientation orientation)
 	{
@@ -56,7 +57,14 @@ class PixbufUtils {
 		return orientation;
 	}
 
-	public static Pixbuf ErrorPixbuf = PixbufUtils.LoadFromAssembly ("f-spot-question-mark.png");
+	static Pixbuf error_pixbuf = null;
+	public static Pixbuf ErrorPixbuf {
+		get {
+			if (error_pixbuf == null)
+				error_pixbuf = GtkUtil.TryLoadIcon (FSpot.Global.IconTheme, "f-spot-question-mark", 256, (Gtk.IconLookupFlags)0);
+			return error_pixbuf;
+		}
+	}
 	public static Pixbuf LoadingPixbuf = PixbufUtils.LoadFromAssembly ("f-spot-loading.png");
 
 	public static int GetSize (Pixbuf pixbuf)
@@ -342,8 +350,7 @@ class PixbufUtils {
 	
 	public static Pixbuf TagIconFromPixbuf (Pixbuf source)
 	{
-		// FIXME 50x50 crashes Pixdata.Serialize... what a mess.
-		int size = 52;
+		int size = (int) Tag.IconSize.Large;
 		Pixbuf tmp = null;
 		Pixbuf icon = null;
 
@@ -538,26 +545,6 @@ class PixbufUtils {
 			throw new System.Exception ("Error Saving File");
 	}
 
-	[DllImport ("libgtk-win32-2.0-0.dll")]
-	extern static IntPtr gtk_icon_theme_get_default ();
-
-	[DllImport ("libgtk-win32-2.0-0.dll")]
-	extern static IntPtr gtk_icon_theme_load_icon (IntPtr theme, string name, int size, int flags, IntPtr error);
-	
-	public static Gdk.Pixbuf LoadThemeIcon (string name, int size)
-	{
-		try {
-			IntPtr native = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), name, size, 0, IntPtr.Zero);
-			if (native != IntPtr.Zero) {
-				Gdk.Pixbuf ret = (Gdk.Pixbuf) GLib.Object.GetObject(native, true);
-				return ret;
-			}
-		} catch (System.Exception e) {
-			System.Console.Write (e.ToString ());
-		}
-		return null;
-	}
-
 
 	[DllImport ("libfspot")]
 	static extern IntPtr f_pixbuf_unsharp_mask (IntPtr src, double radius, double amount, double threshold);
@@ -771,8 +758,9 @@ class PixbufUtils {
 	
 	public static PixbufOrientation GetOrientation (string path)
 	{
-		FSpot.ImageFile img = FSpot.ImageFile.Create (path);
-		return img.Orientation;
+		using (FSpot.ImageFile img = FSpot.ImageFile.Create (path)) {
+			return img.Orientation;
+		}
 	}
 
 	[DllImport("libgnomeui-2-0.dll")]
