@@ -7,6 +7,9 @@ namespace FSpot
 {
 	public class Preferences
 	{
+		public const string APP_FSPOT = "/apps/f-spot/";
+		public const string APP_FSPOT_EXPORT = APP_FSPOT + "export/";
+
 		public const string MAIN_WINDOW_MAXIMIZED = "/apps/f-spot/ui/maximized";
 
 		public const string MAIN_WINDOW_X = "/apps/f-spot/ui/main_window_x";
@@ -33,6 +36,7 @@ namespace FSpot
 		public const string SHOW_TAGS = "/apps/f-spot/ui/show_tags";
 		public const string SHOW_DATES = "/apps/f-spot/ui/show_dates";
 		public const string EXPANDED_TAGS = "/apps/f-spot/ui/expanded_tags";
+		public const string SHOW_RATINGS = "/apps/f-spot/ui/show_ratings";
 		public const string TAG_ICON_SIZE = "/apps/f-spot/ui/tag_icon_size";
 		
 		public const string GLASS_POSITION = "/apps/f-spot/ui/glass_position";
@@ -42,31 +46,10 @@ namespace FSpot
 		public const string SIDEBAR_POSITION = "/apps/f-spot/ui/sidebar_size";
 		public const string ZOOM = "/apps/f-spot/ui/zoom";
 
-		public const string EXPORT_FLICKR_SCALE = "/apps/f-spot/export/flickr/scale";
-		public const string EXPORT_FLICKR_SIZE = "/apps/f-spot/export/flickr/size";
-		public const string EXPORT_FLICKR_BROWSER = "/apps/f-spot/export/flickr/browser";
-		public const string EXPORT_FLICKR_TAGS = "/apps/f-spot/export/flickr/tags";
-		public const string EXPORT_FLICKR_STRIP_META = "/apps/f-spot/export/flickr/strip_meta";
-		public const string EXPORT_FLICKR_EMAIL = "/apps/f-spot/export/flickr/email";
-		public const string EXPORT_FLICKR_PUBLIC = "/apps/f-spot/export/flickr/public";
-		public const string EXPORT_FLICKR_FRIENDS = "/apps/f-spot/export/flickr/friends";
-		public const string EXPORT_FLICKR_FAMILY = "/apps/f-spot/export/flickr/family";
-
 		public const string EXPORT_TOKEN_FLICKR = "/apps/f-spot/export/tokens/flickr"; 
 		public const string EXPORT_TOKEN_23HQ = "/apps/f-spot/export/tokens/23hq"; 
 		public const string EXPORT_TOKEN_ZOOOMR = "/apps/f-spot/export/tokens/zooomr"; 
 
-		public const string EXPORT_GALLERY_SCALE = "/apps/f-spot/export/gallery/scale";
-		public const string EXPORT_GALLERY_SIZE = "/apps/f-spot/export/gallery/size";
-		public const string EXPORT_GALLERY_BROWSER = "/apps/f-spot/export/gallery/browser";
-		public const string EXPORT_GALLERY_META = "/apps/f-spot/export/gallery/meta";
-		public const string EXPORT_GALLERY_ROTATE = "/apps/f-spot/export/gallery/rotate";
-
-		public const string EXPORT_PICASAWEB_SCALE = "/apps/f-spot/export/picasaweb/scale";
-		public const string EXPORT_PICASAWEB_SIZE = "/apps/f-spot/export/picasaweb/size";
-		public const string EXPORT_PICASAWEB_ROTATE = "/apps/f-spot/export/picasaweb/rotate";
-		public const string EXPORT_PICASAWEB_BROWSER = "/apps/f-spot/export/picasaweb/browser";
-
 		public const string EXPORT_SMUGMUG_SCALE = "/apps/f-spot/export/smugmug/scale";
 		public const string EXPORT_SMUGMUG_SIZE = "/apps/f-spot/export/smugmug/size";
 		public const string EXPORT_SMUGMUG_ROTATE = "/apps/f-spot/export/smugmug/rotate";
@@ -87,6 +70,8 @@ namespace FSpot
 
 		public const string IMPORT_GUI_ROLL_HISTORY = "/apps/f-spot/import/gui_roll_history";
 
+		public const string DBUS_READ_ONLY = "/apps/f-spot/dbus/read_only";
+
 		public const string SCREENSAVER_TAG = "/apps/f-spot/screensaver/tag_id";
 
 		public const string STORAGE_PATH = "/apps/f-spot/import/storage_path";
@@ -99,6 +84,7 @@ namespace FSpot
 		public const string GNOME_SCREENSAVER_MODE = "/apps/gnome-screensaver/mode";
 
 		public const string GNOME_MAILTO_COMMAND = "/desktop/gnome/url-handlers/mailto/command";
+		public const string GNOME_MAILTO_ENABLED = "/desktop/gnome/url-handlers/mailto/enabled";
 
 		public const string PROXY_USE_PROXY = "/system/http_proxy/use_http_proxy";
 		public const string PROXY_HOST = "/system/http_proxy/host";
@@ -108,26 +94,27 @@ namespace FSpot
 		public const string PROXY_BYPASS_LIST = "/system/http_proxy/ignore_hosts";
 
 
-		private static GConf.Client client;
-		private static GConf.NotifyEventHandler changed_handler;
-		private static Dictionary<string, object> cache = new Dictionary<string, object>();
-
-		private static GConf.Client Client 
-		{
+		private static IPreferenceBackend backend;
+		private static NotifyChangedHandler changed_handler;
+		private static IPreferenceBackend Backend {
 			get {
-				if (client == null) {
-					client = new GConf.Client ();
-
-					changed_handler = new GConf.NotifyEventHandler (OnSettingChanged);
-					client.AddNotify ("/apps/f-spot", changed_handler);
-					client.AddNotify ("/apps/gnome-screensaver/themes", changed_handler);
-					client.AddNotify ("/apps/gnome-screensaver/mode", changed_handler);
-					client.AddNotify ("/desktop/gnome/url-handlers/mailto/command", changed_handler);
-					client.AddNotify ("/system/http_proxy", changed_handler);
+				if (backend == null) {
+#if !NOGCONF
+					backend = new GConfPreferenceBackend ();
+#else
+					backend = new NullPreferenceBackend ();
+#endif
+					changed_handler = new NotifyChangedHandler (OnSettingChanged);
+					backend.AddNotify ("/apps/f-spot", changed_handler);
+					backend.AddNotify ("/apps/gnome-screensaver/themes", changed_handler);
+					backend.AddNotify ("/apps/gnome-screensaver/mode", changed_handler);
+					backend.AddNotify ("/desktop/gnome/url-handlers/mailto", changed_handler);
+					backend.AddNotify ("/system/http_proxy", changed_handler);
 				}
-				return client;
+				return backend;
 			}
 		}
+		private static Dictionary<string, object> cache = new Dictionary<string, object>();
 
 		public static object GetDefault (string key)
 		{
@@ -145,11 +132,11 @@ namespace FSpot
 					
 			case METADATA_EMBED_IN_IMAGE:
 			case MAIN_WINDOW_MAXIMIZED:
+			case GROUP_ADAPTOR_ORDER_ASC:
 				return false;
 
 			case GROUP_ADAPTOR:
 			case GLASS_POSITION:
-			case GROUP_ADAPTOR_ORDER_ASC:
 				return null;
 
 			case SHOW_TOOLBAR:
@@ -157,19 +144,17 @@ namespace FSpot
 			case SHOW_TIMELINE:
 			case SHOW_TAGS:
 			case SHOW_DATES:
+			case SHOW_RATINGS:
 			case VIEWER_SHOW_FILENAMES:
-			case EXPORT_PICASAWEB_SCALE:
-			case EXPORT_PICASAWEB_ROTATE:
-			case EXPORT_PICASAWEB_BROWSER:
 			case EXPORT_SMUGMUG_SCALE:
 			case EXPORT_SMUGMUG_ROTATE:
 			case EXPORT_SMUGMUG_BROWSER:
 			case EXPORT_FOLDER_SCALE:
 			case EXPORT_FOLDER_SHARPEN:
 			case EXPORT_FOLDER_INCLUDE_TARBALLS:
+			case DBUS_READ_ONLY:
 				return true;
 			
-			case EXPORT_PICASAWEB_SIZE:
 			case EXPORT_SMUGMUG_SIZE:
 			case EXPORT_FOLDER_SIZE:
 				return 800;
@@ -227,9 +212,9 @@ namespace FSpot
 					return val;
 
 				try {
-					val = Client.Get (key);
+					val = Backend.Get (key);
 					cache.Add (key, val);
-				} catch (GConf.NoSuchKeyException) {
+				} catch (NoSuchKeyException) {
 					val = GetDefault (key);
 
 					if (val != null)
@@ -245,26 +230,16 @@ namespace FSpot
 			lock (cache) {
 				try {
 					cache [key] = value;				
-					Client.Set (key, value);
+					Backend.Set (key, value);
 				} catch {
 					Console.WriteLine ("Unable to write this gconf key :"+key);
 				}
 			}
 		}
 
-		public static void SetAsBackground (string path)
-		{
-			Client.Set ("/desktop/gnome/background/color_shading_type", "solid");
-			Client.Set ("/desktop/gnome/background/primary_color", "#000000");
-			Client.Set ("/desktop/gnome/background/picture_options", "stretched");
-			Client.Set ("/desktop/gnome/background/picture_opacity", 100);
-			Client.Set ("/desktop/gnome/background/picture_filename", path);
-			Client.Set ("/desktop/gnome/background/draw_background", true);
-		}
+		public static event NotifyChangedHandler SettingChanged;
 
-		public static event GConf.NotifyEventHandler SettingChanged;
-
-		static void OnSettingChanged (object sender, GConf.NotifyEventArgs args)
+		static void OnSettingChanged (object sender, NotifyEventArgs args)
 		{
 			lock (cache) {
 				if (cache.ContainsKey (args.Key)) {
