@@ -1,5 +1,7 @@
 using Gtk;
 using System;
+using FSpot;
+using FSpot.Utils;
 
 public class TagMenu : Menu {
 	private TagStore tag_store;
@@ -23,7 +25,7 @@ public class TagMenu : Menu {
 		{
 			Value = t;
 			if (t.Icon != null)
-				this.Image = new Gtk.Image (t.Icon);
+				this.Image = new Gtk.Image (t.SizedIcon);
 		}
 
 		public static TagMenuItem IndentedItem (Tag t)
@@ -86,8 +88,8 @@ public class TagMenu : Menu {
 
 		if (NewTagHandler != null) {
 			GtkUtil.MakeMenuSeparator (this);
-			GtkUtil.MakeMenuItem (this, Mono.Unix.Catalog.GetString ("Create New Tag"),
-					"f-spot-new-tag", NewTagHandler, true);
+			GtkUtil.MakeMenuItem (this, Mono.Unix.Catalog.GetString ("Create New Tag..."),
+					"tag-new", NewTagHandler, true);
 		}
 	}
 
