@@ -3,6 +3,7 @@ using Mono.Unix;
 using Gtk;
 using System;
 using System.Collections;
+using Banshee.Database;
 
 namespace FSpot.Database {
 	public static class Updater {
@@ -114,17 +115,140 @@ namespace FSpot.Database {
 
 
 			//Version 6.0, change tag icon f-spot-tag-other to emblem-generic
-			AddUpdate (new Version (6,0),delegate () {
+			AddUpdate (new Version (6,0), delegate () {
 				ExecuteScalar ("UPDATE tags SET icon = \"stock_icon:emblem-generic\" " +
 						" WHERE icon LIKE \"stock_icon:f-spot-other.png\"");
 			});
+
+			//Update to version 7.0, keep photo uri instead of path
+			AddUpdate (new Version (7,0), delegate () {
+				string tmp_photos = MoveTableToTemp ("photos");
+				ExecuteNonQuery ( 
+					"CREATE TABLE photos (" +
+					"	id                 INTEGER PRIMARY KEY NOT NULL," +
+					"       time               INTEGER NOT NULL," +
+					"       uri                STRING NOT NULL," +
+					"       description        TEXT NOT NULL," +
+					"       roll_id            INTEGER NOT NULL," +
+					"       default_version_id INTEGER NOT NULL" +
+					")");
+				ExecuteNonQuery (String.Format (
+					"INSERT INTO photos (id, time, uri, description, roll_id, default_version_id)	" +
+					"SELECT id, time, 'file://' || directory_path || '/' || name, 		" +
+					"description, roll_id, default_version_id FROM {0}", tmp_photos));
+			}, true);
 			
-			// Update to version 7.0
-			//AddUpdate (new Version (7,0),delegate () {
+			// Update to version 8.0, store full version uri
+			AddUpdate (new Version (8,0),delegate () {
+				string tmp_versions = MoveTableToTemp ("photo_versions");
+				ExecuteNonQuery (
+					"CREATE TABLE photo_versions (          " +
+					"       photo_id        INTEGER,        " +
+					"       version_id      INTEGER,        " +
+					"       name            STRING,         " +
+					"       uri             STRING NOT NULL " +
+					")");
+
+				SqliteDataReader reader = ExecuteReader (String.Format (
+						"SELECT photo_id, version_id, name, uri " +
+						"FROM {0}, photos " +
+						"WHERE photo_id = id ", tmp_versions));
+		
+				while (reader.Read ()) {
+					System.Uri photo_uri = new System.Uri (reader [3] as string);
+					string name_without_extension = System.IO.Path.GetFileNameWithoutExtension (photo_uri.AbsolutePath);
+					string extension = System.IO.Path.GetExtension (photo_uri.AbsolutePath);
+
+					string uri = photo_uri.Scheme + "://" + 
+						photo_uri.Host + 
+						System.IO.Path.GetDirectoryName (photo_uri.AbsolutePath) + "/" +
+						name_without_extension + " (" + (reader [2] as string) + ")" + extension;
+					ExecuteNonQuery (new DbCommand (
+						"INSERT INTO photo_versions (photo_id, version_id, name, uri) " +
+						"VALUES (:photo_id, :version_id, :name, :uri)",
+						"photo_id", Convert.ToUInt32 (reader [0]),
+						"version_id", Convert.ToUInt32 (reader [1]),
+						"name", (string)(reader [2]),
+						"uri", uri));
+				}
+
+			}, true);
+			
+			// Update to version 9.0
+			AddUpdate (new Version (9,0),delegate () {
+				string tmp_versions = MoveTableToTemp ("photo_versions");
+				ExecuteNonQuery (
+					"CREATE TABLE photo_versions (          " +
+					"       photo_id        INTEGER,        " +
+					"       version_id      INTEGER,        " +
+					"       name            STRING,         " +
+					"       uri             STRING NOT NULL," +
+					"	protected	BOOLEAN		" +
+					")");
+				ExecuteNonQuery (String.Format (
+					"INSERT INTO photo_versions (photo_id, version_id, name, uri, protected) " +
+					"SELECT photo_id, version_id, name, uri, 0 " +
+					"FROM {0} ", tmp_versions));
+			});
+
+ 			// Update to version 10.0, make id autoincrement
+ 			AddUpdate (new Version (10,0),delegate () {
+ 				string tmp_photos = MoveTableToTemp ("photos");
+ 				ExecuteNonQuery (
+ 					"CREATE TABLE photos (                                     " +
+ 					"	id                 INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, " +
+ 					"	time               INTEGER NOT NULL,	   	   " +
+ 					"	uri		   STRING NOT NULL,		   " +
+ 					"	description        TEXT NOT NULL,	           " +
+ 					"	roll_id            INTEGER NOT NULL,		   " +
+ 					"	default_version_id INTEGER NOT NULL		   " +
+ 					")");
+ 
+ 				ExecuteNonQuery (String.Format (
+ 					"INSERT INTO photos (id, time, uri, description, roll_id, default_version_id) " +
+ 					"SELECT id, time, uri, description, roll_id, default_version_id  " + 
+ 					"FROM  {0} ", tmp_photos));
+ 			}, false);
+ 
+			// Update to version 11.0, rating
+			AddUpdate (new Version (11,0),delegate () {
+ 				string tmp_photos = MoveTableToTemp ("photos");
+ 				Execute (
+ 					"CREATE TABLE photos (                                     " +
+ 					"	id                 INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL, " +
+ 					"	time               INTEGER NOT NULL,	   	   " +
+ 					"	uri		   STRING NOT NULL,		   " +
+ 					"	description        TEXT NOT NULL,	           " +
+ 					"	roll_id            INTEGER NOT NULL,		   " +
+ 					"	default_version_id INTEGER NOT NULL,		   " +
+					"       rating             INTEGER NULL			   " +
+ 					")");
+ 
+ 				Execute (String.Format (
+ 					"INSERT INTO photos (id, time, uri, description, roll_id, default_version_id, rating) " +
+ 					"SELECT id, time, uri, description, roll_id, default_version_id, null  " + 
+ 					"FROM  {0} ", tmp_photos));
+			});
+
+			//Update to version 12.0, remove dead associations, bgo #507950, #488545
+			AddUpdate (new Version (12, 0), delegate () {
+				Execute ("DELETE FROM photo_tags WHERE tag_id NOT IN (SELECT id FROM tags)");
+			});
+			
+			// Update to version 13.0
+			AddUpdate (new Version (13,0), delegate () {
+				Execute ("UPDATE photos SET rating = 0 WHERE rating IS NULL");
+			});
+
+			// Update to version 14.0
+			AddUpdate (new Version (14,0), delegate () {
+				Execute ("UPDATE photos SET rating = 0 WHERE rating IS NULL");
+			});
+
+			// Update to version 14.0
+			//AddUpdate (new Version (14,0),delegate () {
 			//	do update here
 			//});
-
-			
 		}
 
 		public static void Run (Db database)
@@ -214,15 +338,35 @@ namespace FSpot.Database {
 			}
 		}
 
+		private static int Execute (string statement)
+		{
+			return db.Database.Execute (statement);
+		}
+
+		private static int Execute (DbCommand command)
+		{
+			return db.Database.Execute (command);
+		}
+
 		private static void ExecuteNonQuery (string statement)
 		{
 			db.Database.ExecuteNonQuery(statement);
 		}
+
+		private static void ExecuteNonQuery (DbCommand command)
+		{
+			db.Database.ExecuteNonQuery(command);
+		}
 		
 		private static int ExecuteScalar (string statement)
 		{
 			return db.Database.Execute(statement);
 		}
+
+		private static SqliteDataReader ExecuteReader (string statement)
+		{
+			return db.Database.Query (statement);
+		}
 		
 		private static bool TableExists (string table)
 		{
@@ -246,6 +390,9 @@ namespace FSpot.Database {
 			
 			// Get the table definition for the table we are copying
 			string sql = SelectSingleString (String.Format ("SELECT sql FROM sqlite_master WHERE tbl_name = '{0}' ORDER BY type DESC", table_name));
+			
+			// Drop temp table if already exists
+			ExecuteNonQuery ("DROP TABLE IF EXISTS " + temp_name);
 
 			// Change the SQL to create the temp table
 			ExecuteNonQuery (sql.Replace ("CREATE TABLE " + table_name, "CREATE TEMPORARY TABLE " + temp_name));
